<?php

declare(strict_types=1);

namespace Drupal\verify_email\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\TempStore\SharedTempStoreFactory;
use Drupal\verify_email\Service\Verifier;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Returns responses for Verify Email routes.
 */
final class VerifyLink extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    private readonly SharedTempStoreFactory $tempStoreS,
    private readonly Verifier $verifier,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('tempstore.shared'),
      $container->get('verify_email.verifier'),
    );
  }

  /**
   * Verifies the link and logs in.
   */
  public function __invoke(string $key, string $secret): RedirectResponse {
    return $this->verifier->verifyAndLogin($key, $secret);
  }

}
