<?php

namespace Drupal\verify_email\Hook;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Render\BubbleableMetadata;

/**
 * Contains hook implementations for token support.
 */
class TokensHooks {
  use StringTranslationTrait;

  /**
   * Implements hook_token_info().
   */
  #[Hook('token_info')]
  public function tokenInfo(): array {
    $type = [
      'name' => $this->t('Verify Email'),
      'description' => $this->t('Tokens for email verification.'),
    ];

    $tokens = [
      'url' => [
        'name' => $this->t('URL'),
        'description' => $this->t('Url to verify email by logging user in.'),
      ],
    ];

    return [
      'types' => [
        'verify-email' => $type,
      ],
      'tokens' => [
        'verify-email' => $tokens,
      ],
    ];
  }

  /**
   * Implements hook_tokens().
   */
  #[Hook('tokens')]
  public function tokens($type, array $tokens, array $data, array $options, BubbleableMetadata $bubbleable_metadata) {
    $replacements = [];

    // Check if the token type is 'verify-email' and the required data exists.
    if ($type === 'verify-email' && !empty($data['verify-email']) && isset($tokens['url'])) {
      // Replace the 'url' token with the URL from the data.
      $replacements[$tokens['url']] = $data['verify-email']['url'];
    }

    return $replacements;
  }

}
