<?php

namespace Drupal\verify_email\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Hook implementations for verify_email.
 */
class VerifyEmailHooks {

  use StringTranslationTrait;

  /**
   * Implements hook_help().
   */
  #[Hook('help')]
  public function help($route_name, RouteMatchInterface $route_match) {
    switch ($route_name) {
      case 'entity.verify_email.collection':
        return '<p>' . $this->t('Verify Email forms require a user to enter their email address and follow an emailed link. They will then be logged in and redirected to a destination page.');
    }
  }

  /**
   * Implements hook_mail().
   */
  #[Hook('mail')]
  public function mail($key, &$message, $params) {
    if (isset($params['headers'])) {
      $message['headers'] = array_merge($message['headers'], $params['headers']);
    }
    if (!empty($params['from'])) {
      $message['from'] = $params['from'];
    }
    $message['subject'] = $params['subject'];
    $message['body'][] = $params['body'];
  }

}
