<?php

namespace Drupal\verify_email\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\verify_email\Service\VerifyEmailRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;

/**
 * Provides dynamic routes for search.
 */
final class VerifyEmailRoutes implements ContainerInjectionInterface {

  public function __construct(
    protected VerifyEmailRepositoryInterface $verifyEmailRepository,
  ) {}

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('verify_email.verify_email_repository')
    );
  }

  /**
   * Builds an array of entity routes.
   *
   * @return \Symfony\Component\Routing\Route[]
   *   Array of route objects.
   */
  public function routes(): array {

    $routes = [];

    $active_forms = $this->verifyEmailRepository->getActiveVerifyEmailForms();
    foreach ($active_forms as $entity_id => $entity) {
      $routes["verify_email.$entity_id"] = new Route(
        path: $entity->getPath(),
        defaults: [
          '_form' => 'Drupal\verify_email\Form\VerifyEmailForm',
          '_title' => $entity->label(),
          'entity' => $entity_id,
        ],
        requirements: [
          '_access' => 'TRUE',
        ],
        options: [
          'parameters' => [
            'entity' => [
              'type' => 'entity:verify_email',
            ],
          ],
        ],
      );

      // New route for the "/thanks" path with the controller.
      $routes["verify_email.$entity_id.thanks"] = new Route(
        path: $entity->getPath() . '/thanks',
        defaults: [
          '_controller' => 'Drupal\verify_email\Controller\ThankYou::thankYouPage',
          '_title' => 'Thank you',
          'entity' => $entity_id,
        ],
        requirements: [
          '_access' => 'TRUE',
        ],
        options: [
          'parameters' => [
            'entity' => [
              'type' => 'entity:verify_email',
            ],
          ],
        ],
      );
    }

    return $routes;
  }

}
