<?php

declare(strict_types=1);

namespace Drupal\verify_email\Service;

use Drupal\Core\Url;
use Drupal\verify_email\VerifyEmailInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Verify email and log user in.
 */
interface VerifierInterface {

  /**
   * Generate link to verify controller.
   *
   * @param \Drupal\verify_email\VerifyEmailInterface $entity
   *   The VerifyEmail entity.
   * @param string $emailAddress
   *   The email address to generate verify link for.
   *
   * @return \Drupal\Core\Url
   *   The generated URL.
   */
  public function generateLink(VerifyEmailInterface $entity, string $emailAddress): Url;

  /**
   * Generate a verification link and send email.
   *
   * @param \Drupal\verify_email\VerifyEmailInterface $entity
   *   The VerifyEmail entity.
   * @param string $emailAddress
   *   The email address to generate verify link for.
   */
  public function sendVerificationEmail(VerifyEmailInterface $entity, string $emailAddress): void;

  /**
   * Verify the login key and log user in.
   *
   * @param string $loginKey
   *   Unique identifier to log in with.
   * @param string $secret
   *   Random string to check.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirection response to go to after login.
   */
  public function verifyAndLogin(string $loginKey, string $secret): RedirectResponse;

}
