<?php

namespace Drupal\verify_email\Service;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\verify_email\VerifyEmailInterface;

/**
 * Provides interface for repository of verify email entities.
 */
final class VerifyEmailRepository implements VerifyEmailRepositoryInterface {

  /**
   * The search page storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected EntityStorageInterface $storage;

  /**
   * Constructs a new SearchPageRepository.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
  ) {
    $this->storage = $entity_type_manager->getStorage('verify_email');
  }

  /**
   * {@inheritdoc}
   */
  public function getActiveVerifyEmailForms(): array {
    $ids = $this->storage->getQuery()
      ->condition('status', TRUE)
      ->accessCheck(FALSE)
      ->execute();
    return $this->storage->loadMultiple($ids);
  }

  /**
   * {@inheritdoc}
   */
  public function getVerifyEmailForm($id): ?VerifyEmailInterface {
    return $this->storage->load($id);
  }

}
