<?php

declare(strict_types=1);

namespace Drupal\verify_email;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining a verify email form entity type.
 */
interface VerifyEmailInterface extends ConfigEntityInterface {

  /**
   * Return the path of the form.
   *
   * @return string
   *   The path to the verify form.
   */
  public function getPath(): string;

  /**
   * Return the introduction text.
   *
   * @return string
   *   The introduction text of the form.
   */
  public function getIntro(): string;

  /**
   * Return the path of the form.
   *
   * @return string
   *   The path to the verify form.
   */
  public function getEmailSubject(): string;

  /**
   * Return the body of the email message.
   *
   * @return string
   *   The body of the email message.
   */
  public function getEmailBody(): string;

  /**
   * Return the path to redirect to after login.
   *
   * @return string
   *   The path to redirect to after login.
   */
  public function getRedirectPath(): string;

  /**
   * Return the custom thank you message.
   *
   * @return string
   *   The thank you message after email validation.
   */
  public function getThankYouBody(): string;

}
