<?php

declare(strict_types=1);

namespace Drupal\Tests\verify_email\Functional;

use Drupal\Tests\BrowserTestBase;
use PHPUnit\Framework\Attributes\Group;

/**
 * Test description.
 */
#[Group('verify_email')]
final class VerifyEmailSetupTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['verify_email'];

  /**
   * {@inheritdoc}
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Set up the test here.
    $this->adminUser = $this->drupalCreateUser(['administer verify email']);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Test the Verify Email entity configuration form.
   */
  public function testVerifyEmailConfig(): void {
    // Open config page.
    $this->drupalGet('/admin/people/verify-email');
    $this->assertSession()->elementExists('xpath', '//h1[text() = "Verify Email configuration"]');
    $this->assertSession()->pageTextContains('There are no Verify Email forms yet.');
    $this->assertSession()->pageTextContains('Placeholder for future global options.');
    // Add a verify email entity.
    $this->drupalGet('/admin/people/verify-email/add');
    $this->assertSession()->elementExists('xpath', '//h1[text() = "Add a verify email form"]');
    // Assert the field exists in the form.
    $this->assertSession()->fieldExists('thank_you_body');
    $this->assertSession()->elementExists('xpath', '//div[@id="edit-email-body--description"][contains(text(), "Email message to be sent to user. Place token [verify-email:url] to insert the login link.")]');
    $edit = [
      'label' => 'Test verify email',
      'id' => 'test_verify_email',
      'path' => 'test-verify-email',
      'intro' => 'Please enter your email.',
      'email_subject' => 'Your email invite',
      'email_body' => 'Please click this link.',
      'thank_you_body' => 'Thank you message.',
      'redirect_path' => '<front>',
    ];
    $this->submitForm($edit, 'Save');
    $this->assertSession()->addressEquals('/admin/people/verify-email');
    $this->assertSession()->statusMessageContains('Created new example Test verify email.', 'status');
    $this->assertSession()->elementExists('xpath', '//td[text() = "Test verify email"]');
    // Update the verify email form label.
    $this->drupalGet('/admin/people/verify-email/test_verify_email');
    $this->submitForm(['label' => 'Updated label'], 'Save');
    $this->assertSession()->elementExists('xpath', '//td[text() = "Updated label"]');
    // Delete the verify email form.
    $this->drupalGet('/admin/people/verify-email/test_verify_email/delete');
    $this->assertSession()->buttonExists('Delete')->click();
    $this->assertSession()->pageTextContains('There are no Verify Email forms yet.');
  }

  /**
   * Test that an invalid redirect path prevents saving the Verify Email form.
   */
  public function testInvalidRedirectPath(): void {
    // Open the add form.
    $this->drupalGet('/admin/people/verify-email/add');
    $this->assertSession()->elementExists('xpath', '//h1[text() = "Add a verify email form"]');

    // Submit the form with an invalid redirect path.
    $edit = [
      'label' => 'Invalid path test',
      'id' => 'invalid_path_test',
      'path' => 'verify-invalid',
      'intro' => 'Enter your email.',
      'email_subject' => 'Test email invite',
      'email_body' => 'Click this link.',
      'thank_you_body' => 'Thank you.',
      'redirect_path' => '/nonexistent',
    ];
    $this->submitForm($edit, 'Save');

    // Verify the form remains on the add page.
    $this->assertSession()->addressEquals('/admin/people/verify-email/add');

    // Verify the error message.
    $this->assertSession()->statusMessageContains('The redirect path /nonexistent is not valid.', 'error');
  }

}
